## Introduction

A big data competition auxiliary package

## Usage

1.Importing the Package

```
import bdcp
```

2.Obtaining the Data

```
bc = bdcp.connect(username, password, module_id)
```

3.Basic Content Setup

```
bc.setbasic()
```

4.checkpoint

```
bc.get_check(hostname)
```

5.obtain the documentation

```
bc.get_element_detail(element_id)
```

6.obtain abcd

```
bc.get_abcd("")
```

